@@ -4,7 +4,7 @@
 """
    TODO Purpose of the file
    @project: HSPyLib
-   hspylib.app.vault.exception
+   @package: hspylib.app.vault.exception
       @file: exceptions.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -15,7 +15,6 @@
 """
 from hspylib.core.exception.exceptions import HSBaseException
 
-
 class VaultCloseError(HSBaseException):
     """Raised when closing the vault"""
 
